@@ -2,7 +2,7 @@
 
 ARCH=$(cc -print-multiarch)
 
-if test $# -eq 0; then
+function usage() {
     echo "This script compiles dependencies of Scilab for Linux $ARCH."
     echo
     echo "Syntax : $0 <dependency> with dependency equal to:"
@@ -11,12 +11,37 @@ if test $# -eq 0; then
     echo " - 'all': compile all dependencies,"
     echo " - 'binary': configure dev-tools for binary version of Scilab,"
     echo " - 'jar': configure JARs for binary version of Scilab,"
-    echo " - 'fromscratch': 'init' + 'download' + 'all' + 'binary',"
+    echo " - 'fromscratch': 'download' + 'all' + 'binary',"
     echo " - 'archive': Create prerequirements archive."
     echo
+}
+
+if test $# -eq 0; then
+    usage
     exit 42
 fi
 
+# Generate needed variables
+if [ -z "$BRANCH" ]; then
+    BRANCH=$(git rev-parse --abbrev-ref HEAD)
+    echo "BRANCH was not set, set to $BRANCH via git" >&2
+fi
+if [ -z "$CI_DEFAULT_BRANCH" ]; then
+    CI_DEFAULT_BRANCH="main"
+    echo "CI_DEFAULT_BRANCH was not set, set to $CI_DEFAULT_BRANCH" >&2
+fi
+if [ -z "$CI_COMMIT_SHORT_SHA" ]; then
+    CI_COMMIT_SHORT_SHA=$(git rev-parse --short HEAD)
+    echo "CI_COMMIT_SHORT_SHA was not set, set to $CI_COMMIT_SHORT_SHA via git" >&2
+fi
+if [ -z "$ARCH" ]; then
+    ARCH=$(cc -print-multiarch)
+    echo "ARCH was not set, set to $ARCH vi cc." >&2
+fi
+if [ -z "$SCI_VERSION_STRING" ]; then
+    echo "SCI_VERSION_STRING was not set, set to scilab-branch-${BRANCH}-${CI_COMMIT_SHORT_SHA}" >&2
+fi
+
 echo "Scilab prerequirements for $ARCH in branch $BRANCH"
 
 INSTALLROOTDIR=$(pwd)/install
@@ -69,7 +94,7 @@ NCURSES_VERSION=6.4
 LIBXML2_VERSION=2.9.9
 MATIO_VERSION=1.5.28
 OPENSSL_VERSION=1.1.1c
-PCRE_VERSION=8.38
+PCRE2_VERSION=10.43
 SUITESPARSE_VERSION=4.4.5
 TCL_VERSION=8.5.15
 TK_VERSION=8.5.15
@@ -77,8 +102,8 @@ BWIDGET_VERSION=1.9.16
 ZLIB_VERSION=1.2.11
 XZ_VERSION=5.4.4
 JOGL_VERSION=2.5.0
-JCEF_VERSION=99c2f7a9c74b # jcef-99c2f7a+cef-127.3.1+g6cbb30e+chromium-127.0.6533.100
-CEF_VERSION=127.3.1+g6cbb30e+chromium-127.0.6533.100
+JCEF_VERSION=ca49ada5c7e3 # jcef-ca49ada5c7e3+cef-135.0.20+ge7de5c3+chromium-135.0.7049.85
+CEF_VERSION=135.0.20+ge7de5c3+chromium-135.0.7049.85	
 OPENXLSX_VERSION=0.3.2
 LIBARCHIVE_VERSION=3.7.1
 RAPIDJSON_VERSION=24b5e7a
@@ -111,7 +136,7 @@ make_versions() {
     echo "LIBXML2_VERSION       = $LIBXML2_VERSION"
     echo "MATIO_VERSION         = $MATIO_VERSION"
     echo "OPENSSL_VERSION       = $OPENSSL_VERSION"
-    echo "PCRE_VERSION          = $PCRE_VERSION"
+    echo "PCRE2_VERSION         = $PCRE2_VERSION"
     echo "SUITESPARSE_VERSION   = $SUITESPARSE_VERSION"
     echo "TCL_VERSION           = $TCL_VERSION"
     echo "TK_VERSION            = $TK_VERSION"
@@ -150,7 +175,7 @@ download_dependencies() {
     [ ! -f matio-$MATIO_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/matio-$MATIO_VERSION.tar.gz
     [ ! -f openssl-$OPENSSL_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/openssl-$OPENSSL_VERSION.tar.gz
     [ ! -f SuiteSparse-$SUITESPARSE_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/SuiteSparse-$SUITESPARSE_VERSION.tar.gz
-    [ ! -f pcre-$PCRE_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/pcre-$PCRE_VERSION.tar.gz
+    [ ! -f pcre2-$PCRE2_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/pcre2-$PCRE2_VERSION.tar.gz
     [ ! -f ncurses-$NCURSES_VERSION.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/ncurses-$NCURSES_VERSION.tar.gz
     [ ! -f tcl$TCL_VERSION-src.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/tcl$TCL_VERSION-src.tar.gz
     [ ! -f tk$TK_VERSION-src.tar.gz ] && curl -LO https://oos.eu-west-2.outscale.com/scilab-releases-dev/prerequirements-sources/tk$TK_VERSION-src.tar.gz
@@ -210,7 +235,7 @@ make_all() {
     build_zlib
     build_lzma
     build_hdf5
-    build_pcre
+    build_pcre2
     build_fftw
     build_libxml2
     build_arpack
@@ -252,7 +277,7 @@ make_binary_directory() {
     cp -R "$INSTALLUSRDIR/include/Eigen/" "$INSTALLROOTDIR/include/"
     cp -R "$INSTALLUSRDIR/include/rapidjson/" "$INSTALLROOTDIR/include/"
     cp -R "$INSTALLUSRDIR/include/libxml2/" "$INSTALLROOTDIR/include/"
-    cp -R "$INSTALLUSRDIR/include/pcre.h" "$INSTALLROOTDIR/include/"
+    cp -R "$INSTALLUSRDIR/include/pcre2.h" "$INSTALLROOTDIR/include/"
 
     #####################################
     ##### lib/thirdparty/ directory #####
@@ -300,11 +325,8 @@ make_binary_directory() {
     rm -f "$LIBTHIRDPARTYDIR"/libmatio.*
     cp -d "$INSTALLUSRDIR"/lib/libmatio.* "$LIBTHIRDPARTYDIR/"
 
-    rm -f "$LIBTHIRDPARTYDIR"/libpcreposix.*
-    cp -d "$INSTALLUSRDIR"/lib/libpcreposix.* "$LIBTHIRDPARTYDIR/"
-
-    rm -f "$LIBTHIRDPARTYDIR"/libpcre.*
-    cp -d "$INSTALLUSRDIR"/lib/libpcre.* "$LIBTHIRDPARTYDIR/"
+    rm -f "$LIBTHIRDPARTYDIR"/libpcre*.*
+    cp -d "$INSTALLUSRDIR"/lib/libpcre2*.* "$LIBTHIRDPARTYDIR/"
 
     rm -f "$LIBTHIRDPARTYDIR"/libssl.*
     cp -d "$INSTALLUSRDIR"/lib/libssl.* "$LIBTHIRDPARTYDIR/"
@@ -438,7 +460,7 @@ make_jar() {
     rm -rf thirdparty
     mkdir thirdparty
     cd thirdparty || exit 1
-    unzip "$DOWNLOADDIR/thirdparty.zip"
+    unzip -o "$DOWNLOADDIR/thirdparty.zip"
     # remove .jar already managed
     rm gluegen*.jar jogl*.jar jcef*.jar
     # Copy all JARs from thirdparty.zip
@@ -801,23 +823,24 @@ build_ncurses() {
     patchelf --set-soname libscincurses.so.6 "$INSTALLUSRDIR/lib/libscincurses.so.$NCURSES_VERSION"
 }
 
-build_pcre() {
+build_pcre2() {
     cd "$BUILDDIR" || exit 1
 
-    INSTALL_DIR=$BUILDDIR/pcre-$PCRE_VERSION/install_dir
+    INSTALL_DIR=$BUILDDIR/pcre2-$PCRE2_VERSION/install_dir
 
-    tar -xzf "$DOWNLOADDIR/pcre-$PCRE_VERSION.tar.gz"
-    cd pcre-$PCRE_VERSION || exit 1
-    ./configure --enable-utf8 --enable-unicode-properties --prefix=
-    make "-j$(nproc)"
-    make install DESTDIR="$INSTALL_DIR"
+    tar -xzf "$DOWNLOADDIR/pcre2-$PCRE2_VERSION.tar.gz"
+    cd pcre2-$PCRE2_VERSION || exit 1
+    cmake -B build . \
+        -DBUILD_SHARED_LIBS=ON \
+        -DBUILD_STATIC_LIBS=OFF \
+        -DPCRE2_BUILD_PCRE2_8=OFF \
+        -DPCRE2_BUILD_PCRE2_16=OFF \
+        -DPCRE2_BUILD_PCRE2_32=ON
 
-    # shellcheck disable=SC2016
-    sed -i -e 's|^prefix=.*|prefix=$( cd -- "$(dirname "$0")" >/dev/null 2>\&1 ; pwd -P )/..|' "$INSTALL_DIR/bin/pcre-config"
-    cp "$INSTALL_DIR/bin/pcre-config" "$INSTALLUSRDIR/bin/"
+    cmake --build build/
 
-    cp -a "$INSTALL_DIR"/lib/*.so* "$INSTALLUSRDIR/lib/"
-    cp -a "$INSTALL_DIR"/include/* "$INSTALLUSRDIR/include/"
+    cp -a build/*.so* "$INSTALLUSRDIR/lib/"
+    cp -a build/pcre2.h "$INSTALLUSRDIR/include/"
 }
 
 build_libxml2() {
@@ -896,7 +919,7 @@ build_libarchive() {
     LDFLAGS="$LDFLAGS -L$INSTALLUSRDIR/lib"
 
     ./configure --prefix= \
-        --enable-posix-regex-lib=libpcreposix
+        --disable-posix-regex-lib
     make "-j$(nproc)"
     make install DESTDIR="$INSTALL_DIR"
 
@@ -939,7 +962,11 @@ build_suitesparse() {
     AMD_MAJOR_VERSION=$(echo "$AMD_VERSION" | awk -F \. '{ print $1}')
     cd AMD/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libamd.so.${AMD_MAJOR_VERSION}" -o "libamd.so.${AMD_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libamd.so.${AMD_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libamd.so.${AMD_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libamd.so*
     cp "libamd.so.${AMD_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -949,7 +976,11 @@ build_suitesparse() {
     CAMD_MAJOR_VERSION=$(echo "$CAMD_VERSION" | awk -F \. '{print $1}')
     cd CAMD/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libcamd.so.${CAMD_MAJOR_VERSION}" -o "libcamd.so.${CAMD_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libcamd.so.${CAMD_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libcamd.so.${CAMD_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libcamd.so*
     cp "libcamd.so.${CAMD_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -959,7 +990,11 @@ build_suitesparse() {
     COLAMD_MAJOR_VERSION=$(echo "$COLAMD_VERSION" | awk -F \. '{print $1}')
     cd COLAMD/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libcolamd.so.${COLAMD_MAJOR_VERSION}" -o "libcolamd.so.${COLAMD_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libcolamd.so.${COLAMD_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libcolamd.so.${COLAMD_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libcolamd.so*
     cp "libcolamd.so.${COLAMD_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -969,7 +1004,11 @@ build_suitesparse() {
     CCOLAMD_MAJOR_VERSION=$(echo "$CCOLAMD_VERSION" | awk -F \. '{print $1}')
     cd CCOLAMD/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libccolamd.so.${CCOLAMD_MAJOR_VERSION}" -o "libccolamd.so.${CCOLAMD_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libccolamd.so.${CCOLAMD_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libccolamd.so.${CCOLAMD_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libccolamd.so*
     cp "libccolamd.so.${CCOLAMD_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -979,7 +1018,11 @@ build_suitesparse() {
     CHOLMOD_MAJOR_VERSION=$(echo "$CHOLMOD_VERSION" | awk -F \. '{print $1}')
     cd CHOLMOD/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libcholmod.so.${CHOLMOD_MAJOR_VERSION}" -o "libcholmod.so.${CHOLMOD_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libcholmod.so.${CHOLMOD_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libcholmod.so.${CHOLMOD_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libcholmod.so*
     cp "libcholmod.so.${CHOLMOD_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -989,7 +1032,11 @@ build_suitesparse() {
     BTF_MAJOR_VERSION=$(echo "$BTF_VERSION" | awk -F \. '{print $1}')
     cd BTF/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libbtf.so.${BTF_MAJOR_VERSION}" -o "libbtf.so.${BTF_VERSION}" $(ls ./*.o)
+    gcc -shared \
+        "-Wl,-soname,libbtf.so.${BTF_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libbtf.so.${BTF_VERSION}" \
+        $(ls ./*.o)
     rm -f "$INSTALLUSRDIR"/lib/libbtf.so*
     cp "libbtf.so.${BTF_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -999,7 +1046,11 @@ build_suitesparse() {
     KLU_MAJOR_VERSION=$(echo "$KLU_VERSION" | awk -F \. '{print $1}')
     cd KLU/Lib/ || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libklu.so.${KLU_MAJOR_VERSION}" -o "libklu.so.${KLU_VERSION}" $(ls ./*.o) \
+    gcc -shared \
+        "-Wl,-soname,libklu.so.${KLU_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libklu.so.${KLU_VERSION}" \
+        $(ls ./*.o) \
         "$INSTALLUSRDIR/lib/libamd.so.${AMD_VERSION}" "$INSTALLUSRDIR/lib/libcolamd.so.${COLAMD_VERSION}" \
         "$INSTALLUSRDIR/lib/libbtf.so.${BTF_VERSION}"
     rm -f "$INSTALLUSRDIR"/lib/libklu.so*
@@ -1011,14 +1062,18 @@ build_suitesparse() {
     UMFPACK_MAJOR_VERSION=$(echo "$UMFPACK_VERSION" | awk -F \. '{print $1}')
     cd UMFPACK/Lib || exit 1
     # shellcheck disable=SC2046
-    gcc -shared "-Wl,-soname,libumfpack.so.${UMFPACK_MAJOR_VERSION}" -o "libumfpack.so.${UMFPACK_VERSION}" $(ls ./*.o) \
-      "$INSTALL_DIR/lib/libsuitesparseconfig.a" \
-      /usr/local/lib/libscigfortran.so.5 /usr/local/lib/libsciquadmath.so.0 \
-      "$INSTALLUSRDIR/lib/libblas.so.3" "$INSTALLUSRDIR/lib/liblapack.so.3" -lm -lrt \
-      "$INSTALLUSRDIR/lib/libcholmod.so.${CHOLMOD_VERSION}" "$INSTALLUSRDIR/lib/libcolamd.so.${COLAMD_VERSION}" \
-      "$INSTALLUSRDIR/lib/libccolamd.so.${CCOLAMD_VERSION}" "$INSTALLUSRDIR/lib/libcamd.so.${CAMD_VERSION}" \
-      "$INSTALLUSRDIR/lib/libbtf.so.${BTF_VERSION}" "$INSTALLUSRDIR/lib/libklu.so.${KLU_VERSION}" \
-      "$INSTALLUSRDIR/lib/libamd.so.${AMD_VERSION}"
+    gcc -shared \
+        "-Wl,-soname,libumfpack.so.${UMFPACK_MAJOR_VERSION}" \
+        -Wl,-rpath='$ORIGIN' \
+        -o "libumfpack.so.${UMFPACK_VERSION}" \
+        $(ls ./*.o) \
+        "$INSTALL_DIR/lib/libsuitesparseconfig.a" \
+        /usr/local/lib/libscigfortran.so.5 /usr/local/lib/libsciquadmath.so.0 \
+        "$INSTALLUSRDIR/lib/libblas.so.3" "$INSTALLUSRDIR/lib/liblapack.so.3" -lm -lrt \
+        "$INSTALLUSRDIR/lib/libcholmod.so.${CHOLMOD_VERSION}" "$INSTALLUSRDIR/lib/libcolamd.so.${COLAMD_VERSION}" \
+        "$INSTALLUSRDIR/lib/libccolamd.so.${CCOLAMD_VERSION}" "$INSTALLUSRDIR/lib/libcamd.so.${CAMD_VERSION}" \
+        "$INSTALLUSRDIR/lib/libbtf.so.${BTF_VERSION}" "$INSTALLUSRDIR/lib/libklu.so.${KLU_VERSION}" \
+        "$INSTALLUSRDIR/lib/libamd.so.${AMD_VERSION}"
     rm -f "$INSTALLUSRDIR"/lib/libumfpack.so*
     cp "libumfpack.so.${UMFPACK_VERSION}" "$INSTALLUSRDIR/lib/"
     cd ../..
@@ -1080,7 +1135,7 @@ build_jcef() {
 
     cd "$BUILDDIR" || exit 1
 
-    unzip "$DOWNLOADDIR/chromiumembedded-java-cef-$JCEF_VERSION.zip"
+    unzip -o "$DOWNLOADDIR/chromiumembedded-java-cef-$JCEF_VERSION.zip"
     tar -xjf "$DOWNLOADDIR/cef_binary_${CEF_VERSION}_linux64.tar.bz2" -C "chromiumembedded-java-cef-$JCEF_VERSION/third_party/cef/"
     cd chromiumembedded-java-cef-$JCEF_VERSION || exit 1
 
@@ -1264,6 +1319,13 @@ do
         shift
         ;;
     *)
+        if declare -F "build_$1" > /dev/null; then
+            echo "Building $1"
+        else
+            echo "Unknown function: build_$1"
+            usage
+            exit 1
+        fi
         create_folders
         eval "build_$1"
         shift
