@@ -49,6 +49,10 @@ void TreeVisitor::visit(const SeqExp  &e)
         {
             continue;
         }
+        if (it->isClassDec())
+        {
+            continue;
+        }
 
         if (it->isAssignExp() ||
                 it->isCommentExp() ||
@@ -1173,12 +1177,12 @@ types::List* TreeVisitor::matrixOrCellExp(const exps_t& lines, TreeVisitor& me,
     types::List* sub = createOperation();
     types::List* ope = new types::List();
     ast::exps_t::const_iterator	i, j;
-    
+
     int idx = 0;
     for (i = lines.begin() ; i != lines.end() ; )
     {
         (*i)->accept(me);
-        
+
         if (idx >= 2)
         {
             sub->append(ope);
@@ -1211,7 +1215,7 @@ types::List* TreeVisitor::matrixOrCellExp(const exps_t& lines, TreeVisitor& me,
         {
             ope->append(me.getEOL());
         }
-        ++idx;
+	++idx;
     }
 
     sub->append(ope);
