@@ -20,6 +20,7 @@
 #include "types_tools.hxx"
 #include "overload.hxx"
 #include "scilabWrite.hxx"
+#include "commentexp.hxx"
 
 extern "C"
 {
@@ -947,6 +948,19 @@ types::Function::ReturnValue VariableToString(types::InternalType* pIT, const wc
 {    
     if (pIT->hasToString() == false)
     {
+        if (pIT->isObject())
+        {
+            types::Object* obj = pIT->getAs<types::Object>();
+            if (obj->hasMethod(L"disp"))
+            {
+                types::typed_list in;
+                types::optional_list opt;
+                types::typed_list out;
+                types::Function::ReturnValue ret = obj->callMethod(L"disp", in, opt, 0, out, ast::CommentExp(Location(), new std::wstring(L"")));
+                return ret;
+            }
+        }
+
         types::Function::ReturnValue ret = types::Function::Error;
         //call overload %type_p
         types::typed_list in;
